@@ -23,61 +23,15 @@
 
 #include "ApiRequest.h"
 
+#include "ApiRequest_p.h"
+
 #include "UrlBuilder.h"
 #include "JsonCreator.h"
-#include "RequestHandler.h"
 
+#include <QString>
+#include <QByteArray>
 #include <QLatin1String>
 
-namespace mygpo
-{
-
-class ApiRequestPrivate
-{
-public:
-    //Constructors
-    ApiRequestPrivate( const QString& username, const QString& password, QNetworkAccessManager* nam );
-    ApiRequestPrivate( QNetworkAccessManager* nam );
-    //Member Functions
-    QNetworkReply* toplistOpml( uint count );
-    QNetworkReply* searchOpml( const QString& query );
-    QNetworkReply* suggestionsOpml( uint count );
-	QNetworkReply* toplistTxt( uint count );
-    QNetworkReply* searchTxt( const QString& query );
-    QNetworkReply* suggestionsTxt( uint count );
-    PodcastListPtr toplist( uint count );
-    PodcastListPtr search( const QString& query );
-    PodcastListPtr suggestions( uint count );
-    PodcastListPtr podcastsOfTag( uint count, const QString& tag );
-    PodcastPtr podcastData( const QUrl& podcasturl );
-    EpisodePtr episodeData( const QUrl& podcasturl, const QUrl& episodeurl );
-    EpisodeListPtr favoriteEpisodes( const QString& username );
-    TagListPtr topTags( uint count );
-    AddRemoveResultPtr addRemoveSubscriptions( const QString& username, const QString& device, const QList< QUrl >& add, const QList< QUrl >& remove );
-    SettingsPtr accountSettings( const QString& username );
-    SettingsPtr deviceSettings( const QString& username, const QString& device );
-    SettingsPtr podcastSettings( const QString& username, const QString& podcastUrl );
-    SettingsPtr episodeSettings( const QString& username, const QString& podcastUrl, const QString& episodeUrl );
-    SettingsPtr setAccountSettings( const QString& username, QMap<QString, QVariant >& set, const QList<QString>& remove );
-    SettingsPtr setDeviceSettings( const QString& username, const QString& device, QMap<QString, QVariant >& set, const QList<QString>& remove );
-    SettingsPtr setPodcastSettings( const QString& username, const QString& podcastUrl, QMap<QString, QVariant >& set, const QList<QString>& remove );
-    SettingsPtr setEpisodeSettings( const QString& username, const QString& podcastUrl, const QString& episodeUrl, QMap<QString, QVariant >& set, const QList<QString>& remove );
-    DeviceUpdatesPtr deviceUpdates( const QString& username, const QString& deviceId, qlonglong timestamp );
-    QNetworkReply* renameDevice( const QString& username, const QString& deviceId, const QString& caption, Device::Type type );
-    DeviceListPtr listDevices( const QString& username );
-    EpisodeActionListPtr episodeActions( const QString& username, const bool aggregated );
-    EpisodeActionListPtr episodeActionsByPodcast( const QString& username, const QString& podcastUrl, const bool aggregated );
-    EpisodeActionListPtr episodeActionsByDevice( const QString& username, const QString& deviceId, const bool aggregated );
-    EpisodeActionListPtr episodeActionsByTimestamp( const QString& username, const qulonglong since );
-    EpisodeActionListPtr episodeActionsByPodcastAndTimestamp( const QString& username, const QString& podcastUrl, const qulonglong since );
-    EpisodeActionListPtr episodeActionsByDeviceAndTimestamp( const QString& username, const QString& deviceId, const qulonglong since );
-    AddRemoveResultPtr uploadEpisodeActions( const QString& username, const QList<EpisodeActionPtr>& episodeActions );
-private:
-    RequestHandler m_requestHandler;
-};
-
-}
-
 using namespace mygpo;
 
 ApiRequestPrivate::ApiRequestPrivate( const QString& username, const QString& password, QNetworkAccessManager* nam ) : m_requestHandler( username, password, nam )
